import java.io.*;
import javax.servlet.http.*;
import javax.servlet.*;
import java.rmi.*;
import javax.naming.InitialContext;

/**
  * CustomLoginServlet
  *
  * Process a custom HTML 'login' form (HTML form attached at the bottom of
  * this class) and performs a login using the login() method found within the
  * the base class (LoginServlet).
  *
  * This sample servlet is used as an example of the Custom Login feature of
  * WebSphere S/A 3.02.
  *
 */

public class CustomLoginServlet extends AbstractLoginServlet {

   // Strings
   private String defaultRedirectUrl = null;
	private static final String hdrName = "WASReqURL";

  /**
    * init
    *
    * Initializes the servlet. Reads and processes parameters to servlet
    *
   */
   public void init(ServletConfig conf) throws ServletException {

      super.init(conf);  

      // read the default redirect URL for this servlet (...if it exists).
      defaultRedirectUrl = getInitParameter ("DefaultRedirectURL");
   }



  /**
    * doPost
    *
    * The doPost method is the primary entry point of this servlet.  It is designed
    * to called as the result of an HTML form post.  This servlet will 
    * read and validate the posted parameters, then call the 'login' API found
    *in the base class (LoginServlet)
    *
    * @param      req    the request object 
    * @param      res    the response object
    * @return     <code>void</void>
    * @exception  IOException problem reading from or writing to
    *             the req or res streams
   */
   public void doPost (HttpServletRequest req, HttpServletResponse res)
   throws ServletException, IOException {  

      String userId=null;                      // user id found on form
      String userPw=null;                      // password
      String redirectURL=null;                 // redirect url

      userId =req.getParameter("userid");      // obtain userid data form 
      userPw =req.getParameter("password");    // obtain password from form
		
      redirectURL =req.getParameter("jumpto"); // obtain redirect url from form

		if (redirectURL == null) {
			redirectURL = getRefererURL(req, res);
			if ((redirectURL == null) || (redirectURL.equals("")) ) {
				// if referer is not obtained, use default Redirect URL;
				redirectURL = defaultRedirectUrl;
			}
		}

      
      int err;                                 // validate parameters
      if ( (err=checkParams( userId, userPw,
                            redirectURL))!=0) {  
         showInvalidParameterPage(err, res);   // display error page
         return;
      }

      // perform the log on
		res.setContentType("text/html");
		PrintWriter out = res.getWriter();
      boolean success = false;
		
		boolean setSSO = true;

		try {
         login( req, res, setSSO, userId, userPw, redirectURL );
			success = true;
      } catch (ServletException se) {
         out.println("CustomLoginServlet:  ERROR logging on"+se);
      }
   }

  /**
    * postLogin
    *
    * The postLogin method is called after a login has successfully occured.
    * This method is a good place to establish a HTTP session or other actions
    * that relate to the Logged on user.   This code is now running under the
    * identity of the user
    *
    * @param      req    the request object 
    * @param      res    the response object
    * @return     <code>void</void>
    * @exception  IOException problem reading from or writing to
    *             the req or res streams
   */
   public void postLogin( HttpServletRequest req, HttpServletResponse res)
   throws ServletException {
                            
       
   }
   
  /**
    * checkParams
    *
    * Check the values of the parameters read from the HTML login form
    *
    * @param      userId  the userid
    * @param      userPw  the Password
    * @param      redirectURL the url to jump to a successful after login
    * @return     <code>int</code> error 1=userid, 2=password, 3=other
    *
   */
   private int checkParams( String userId, String userPw, String redirectURL) {
      int err=0;   // zero mean no error

      // validate userid
      if (!(userId != null && (userId.length()!=0)) ) {
         // Invalid userID (empty string)
         err=1;
         return err;
      }

      // validate password
      if (!(userPw != null && (userPw.length()!=0)) ) {
         // Invalid Password (empty string)
         err=2;
         return err;
      }

      // validate redirect URL
      if (!(redirectURL != null && (redirectURL.length()!=0)) ) {
         // Invalid redirect URL (empty string)
         err=3;
         return err;
      }
      return err;
   }

   /**
    * showInvalidParameterPage
    *
    * Displays an error page...
    *
    * @param      err    they type of error encountered 1=bad userid, 2=bad password
    * @param      res    the response object
    * @return     <code>void</void>
    * @exception  IOException problem reading from or writing to
    *             the req or res streams
   */
   private void showInvalidParameterPage( int err, HttpServletResponse res)
   throws ServletException, IOException {

  
      ServletOutputStream out = res.getOutputStream();
      
      out.println("<html>");
      out.println("<head><title>Invalid Login Parameter</title></head>");
      out.println("<body>");
      out.println("<h1>Invalid Login Parameter</h1>");
      out.print("<p><strong>");
      if (err==1) {
         out.print("Invalid UserID");
      } else if (err==2) {
         out.print("Invalid UserID");
      } else {
         out.print("Invalid redirect URL");
      }
      out.println("</strong>");
      out.println("</body></html>");
      out.close();
   }

   public String getServletInfo(){
      return "CustomLoginServlet";
   }

}

        
     

